@@ -130,7 +130,7 @@ Shlomi Fish, L<http://www.shlomifish.org/>.
 
 Please report any bugs or feature requests to
 C<bug-xml-grammar-screenplay at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Screeplay>.
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Screenplay>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
